diff --git a/docs/setup/schema.md b/docs/setup/schema.md
index 11d8ef6..61bdc70 100644
--- a/docs/setup/schema.md
+++ b/docs/setup/schema.md
@@ -75,7 +75,7 @@ database:
},
"storage" : {
"temporary" : "/payloads", // storage path used for storing received instances before uploading to Clara Platform.
- "watermarkPercent": 85, // storage space usage watermark to stop storing, exporting and retrieving of DICOM instances.
+ "watermarkPercent": 75, // storage space usage watermark to stop storing, exporting and retrieving of DICOM instances.
"reserveSpaceGB": 5 // minimal storage space required to store, export and retrieve DICOM instances.
}
},
diff --git a/docs/setup/setup.md b/docs/setup/setup.md
index 63ec04c..ccec000 100644
--- a/docs/setup/setup.md
+++ b/docs/setup/setup.md
@@ -66,7 +66,7 @@ The default settings enable DICOM *C-STORE SCP* and *C-STORE-SCU* and set listen
},
"storage" : {
"temporary" : "/payloads",
- "watermarkPercent": 85,
+ "watermarkPercent": 75,
"reserveSpaceGB": 5
}
},
diff --git a/helm-chart/dicom-adapter/files/appsettings.json b/helm-chart/dicom-adapter/files/appsettings.json
index 75ad240..0b795fb 100644
--- a/helm-chart/dicom-adapter/files/appsettings.json
+++ b/helm-chart/dicom-adapter/files/appsettings.json
@@ -17,7 +17,7 @@
},
"storage" : {
"temporary" : "/payloads",
- "watermarkPercent": 85,
+ "watermarkPercent": 75,
"reserveSpaceGB": 5
},
"services": {
diff --git a/helm-chart/ngc/overview.md b/helm-chart/ngc/overview.md
index 4745af0..4be9300 100644
--- a/helm-chart/ngc/overview.md
+++ b/helm-chart/ngc/overview.md
@@ -1,7 +1,7 @@
# Clara DICOM Adapter Helm Chart
This asset requires the Clara Deploy SDK. Follow the instructions on the
-[Clara Bootstrap]($NGC_HOST/model-scripts/$NGC_ORG:$NGC_TEAM:clara_bootstrap) page
+[Clara Ansible]($NGC_HOST/model-scripts/$NGC_ORG:$NGC_TEAM:clara_ansible) page
to install the Clara Deploy SDK.
## Install via Clara CLI
diff --git a/src/Configuration/StorageConfiguration.cs b/src/Configuration/StorageConfiguration.cs
index 90f095e..413350f 100644
--- a/src/Configuration/StorageConfiguration.cs
+++ b/src/Configuration/StorageConfiguration.cs
@@ -37,14 +37,14 @@ public StorageConfiguration(IFileSystem fileSystem)
public string Temporary { get; set; } = "./payloads";
///
/// Gets or sets the watermark for disk usage with default value of 85%,
/// meaning that DICOM Adapter will stop accepting (C-STORE-RQ) assocations,
/// stop exporting and stop retreiving data via DICOMweb when used disk space
/// is above the watermark.
///
///
[JsonProperty(PropertyName = "watermarkPercent")]
- public uint Watermark { get; set; } = 85;
+ public uint Watermark { get; set; } = 75;
///
/// Gets or sets the reserved disk space for DICOM Adapter with default value of 5GB.
@@ -37,14 +37,14 @@ public StorageConfiguration(IFileSystem fileSystem)
public string Temporary { get; set; } = "./payloads";
///
- /// Gets or sets the watermark for disk usage with default value of 85%,
+ /// Gets or sets the watermark for disk usage with default value of 75%,
/// meaning that DICOM Adapter will stop accepting (C-STORE-RQ) assocations,
/// stop exporting and stop retreiving data via DICOMweb when used disk space